==> zapp-react-native-ui-components-11.1.24-rc.0.tgz: package/Components/Transitioner/Scene.tsx <==
import React from "react";
import {
  Animated,
  useWindowDimensions,
  ViewProps,
  ViewStyle,
} from "react-native";
import { useSafeAreaFrame } from "react-native-safe-area-context";
import { PathnameContext } from "../../Contexts/PathnameContext";

type Props = {
  children: any;
  style: any;
  pointerEvents: ViewProps["pointerEvents"];
  overlayStyle: ViewStyle;
  animating: boolean;
  contentStyle: ViewStyle;
  pathname: string;
};

/**
 * Animated View container for any purpose.
 * Renders given children with given style object.
 * Optional property: pointer event (e.g. to prevent interaction with animating scene).
 * @param {React.Component} children Just about anything
 * @param {object} style             Container style
 * @param {} pointerEvents           box-none|none|box-only|auto (default)
 * @param overlayStyle
 * @param animating
 * @param contentStyle
 * @param screenUniqueId
 */
export function Scene({
  children,
  style,
  pointerEvents = "auto",
  overlayStyle,
  animating,
  contentStyle,
  pathname,
}: Props) {
  const frame = useSafeAreaFrame();
  const { height, width } = useWindowDimensions();

  if (overlayStyle && animating) {
    // Safe frame takes too long to update,
    // so we can not rely on it there, and use height and width instead.
    return (
      <Animated.View
        pointerEvents={pointerEvents}
        style={[style, contentStyle, { height, width }]}
      >
        <PathnameContext.Provider value={pathname}>
          {children}
        </PathnameContext.Provider>
        <Animated.View style={overlayStyle} />
      </Animated.View>
    );
  }

  return (
    <Animated.View
      pointerEvents={pointerEvents}
      style={[style, contentStyle, frame]}
    >
      <PathnameContext.Provider value={pathname}>
        {children}
      </PathnameContext.Provider>
    </Animated.View>
  );
}

==> zapp-react-native-ui-components-12.0.0-rc.88.tgz: package/Components/Transitioner/Scene.tsx <==
import React from "react";
import {
  Animated,
  useWindowDimensions,
  ViewProps,
  ViewStyle,
} from "react-native";
import { useSafeAreaFrame } from "react-native-safe-area-context";
import { PathnameContext } from "../../Contexts/PathnameContext";
import { ScreenDataContext } from "../../Contexts/ScreenDataContext";

type Props = {
  children: any;
  style: any;
  pointerEvents: ViewProps["pointerEvents"];
  overlayStyle: ViewStyle;
  animating: boolean;
  contentStyle: ViewStyle;
  pathname: string;
  isActive: boolean;
  screenData: NavigationScreenData;
};

/**
 * Animated View container for any purpose.
 * Renders given children with given style object.
 * Optional property: pointer event (e.g. to prevent interaction with animating scene).
 * @param {React.Component} children Just about anything
 * @param {object} style             Container style
 * @param {} pointerEvents           box-none|none|box-only|auto (default)
 * @param overlayStyle
 * @param animating
 * @param contentStyle
 * @param screenUniqueId
 */
export function Scene({
  children,
  style,
  pointerEvents = "auto",
  overlayStyle,
  animating,
  contentStyle,
  pathname,
  isActive = false,
  screenData,
}: Props) {
  const [initialScreenData, setInitialScreenData] = React.useState(screenData);

  React.useLayoutEffect(() => {
    if (isActive) {
      setInitialScreenData(screenData);
    }
  }, [screenData, isActive]);

  const frame = useSafeAreaFrame();
  const { height, width } = useWindowDimensions();

  // Safe frame takes too long to update,
  // so we can not rely on it there, and use height and width instead.
  const isAnimating = animating && overlayStyle;
  const dimensions = isAnimating ? { height, width } : frame;

  return (
    <Animated.View
      pointerEvents={pointerEvents}
      style={[style, contentStyle, dimensions]}
    >
      <ScreenDataContext.Provider value={initialScreenData}>
        <PathnameContext.Provider value={pathname}>
          {children}
        </PathnameContext.Provider>
      </ScreenDataContext.Provider>
      {isAnimating && <Animated.View style={overlayStyle} />}
    </Animated.View>
  );
}
